--- old/usr/src/head/iso/math_c99.h	2019-06-04 01:04:25.665332691 +0000
+++ new/usr/src/head/iso/math_c99.h	2019-06-04 01:04:25.682808335 +0000
@@ -66,13 +66,13 @@
 #undef	isnan
 #undef	isinf
 #if __GNUC__ >= 4
-#define	isnan(x)	__builtin_isnan(x)
-#define	isinf(x)	__builtin_isinf(x)
 #define	fpclassify(x)	__builtin_fpclassify(FP_NAN, FP_INFINITE, FP_NORMAL, \
     FP_SUBNORMAL, FP_ZERO, x)
-#define	isfinite(x)	__builtin_isfinite(x)
-#define	isnormal(x)	__builtin_isnormal(x)
-#define	signbit(x)	(__builtin_signbit(x) > 0)
+#define	isnan(x)	__builtin_isnan(x)
+#define	isinf(x)	__builtin_isinf(x)
+#define	isfinite(x)	(__builtin_isfinite(x) != 0)
+#define	isnormal(x)	(__builtin_isnormal(x) != 0)
+#define	signbit(x)	(__builtin_signbit(x) != 0)
 #else  /* __GNUC__ >= 4 */
 #define	isnan(x)	__extension__( \
 			{ __typeof(x) __x_n = (x); \
--- old/usr/src/lib/libm/common/C/jn.c	2019-06-04 01:04:26.134487905 +0000
+++ new/usr/src/lib/libm/common/C/jn.c	2019-06-04 01:04:26.150938928 +0000
@@ -69,7 +69,8 @@
 	one	= 1.0;
 
 GENERIC
-jn(int n, GENERIC x) {
+jn(int n, GENERIC x)
+{
 	int i, sgn;
 	GENERIC a, b, temp = 0;
 	GENERIC z, w, ox, on;
@@ -78,16 +79,18 @@
 	 * J(-n,x) = (-1)^n * J(n, x), J(n, -x) = (-1)^n * J(n, x)
 	 * Thus, J(-n,x) = J(n,-x)
 	 */
-	ox = x; on = (GENERIC)n;
+	ox = x;
+	on = (GENERIC)n;
+
 	if (n < 0) {
 		n = -n;
 		x = -x;
 	}
 	if (isnan(x))
 		return (x*x);	/* + -> * for Cheetah */
-	if (!((int) _lib_version == libm_ieee ||
-		(__xpg6 & _C99SUSv3_math_errexcept) != 0)) {
-	    if (fabs(x) > X_TLOSS)
+	if (!((int)_lib_version == libm_ieee ||
+	    (__xpg6 & _C99SUSv3_math_errexcept) != 0)) {
+		if (fabs(x) > X_TLOSS)
 			return (_SVID_libm_err(on, ox, 38));
 	}
 	if (n == 0)
@@ -95,7 +98,7 @@
 	if (n == 1)
 		return (j1(x));
 	if ((n&1) == 0)
-		sgn = 0; 			/* even n */
+		sgn = 0;			/* even n */
 	else
 		sgn = signbit(x);	/* old n  */
 	x = fabs(x);
@@ -105,7 +108,7 @@
 					 * Safe to use
 					 *  J(n+1,x)=2n/x *J(n,x)-J(n-1,x)
 					 */
-	    if (x > 1.0e91) {
+		if (x > 1.0e91) {
 				/*
 				 * x >> n**2
 				 *    Jn(x) = cos(x-(2n+1)*pi/4)*sqrt(2/x*pi)
@@ -116,124 +119,144 @@
 				 *	   n	sin(xn)*sqt2	cos(xn)*sqt2
 				 *	----------------------------------
 				 *	   0	 s-c		 c+s
-				 *	   1	-s-c 		-c+s
+				 *	   1	-s-c		-c+s
 				 *	   2	-s+c		-c-s
 				 *	   3	 s+c		 c-s
 				 */
-		switch (n&3) {
-		    case 0: temp =  cos(x)+sin(x); break;
-		    case 1: temp = -cos(x)+sin(x); break;
-		    case 2: temp = -cos(x)-sin(x); break;
-		    case 3: temp =  cos(x)-sin(x); break;
-		}
-		b = invsqrtpi*temp/sqrt(x);
-	    } else {
+			switch (n&3) {
+			case 0:
+				temp =  cos(x)+sin(x);
+				break;
+			case 1:
+				temp = -cos(x)+sin(x);
+				break;
+			case 2:
+				temp = -cos(x)-sin(x);
+				break;
+			case 3:
+				temp =  cos(x)-sin(x);
+				break;
+			}
+			b = invsqrtpi*temp/sqrt(x);
+		} else {
 			a = j0(x);
 			b = j1(x);
 			for (i = 1; i < n; i++) {
-		    temp = b;
-		    b = b*((GENERIC)(i+i)/x) - a; /* avoid underflow */
-		    a = temp;
+				temp = b;
+				/* avoid underflow */
+				b = b*((GENERIC)(i+i)/x) - a;
+				a = temp;
 			}
-	    }
-	} else {
-	    if (x < 1e-9) {	/* use J(n,x) = 1/n!*(x/2)^n */
-		b = pow(0.5*x, (GENERIC) n);
-		if (b != zero) {
-		    for (a = one, i = 1; i <= n; i++) a *= (GENERIC)i;
-		    b = b/a;
 		}
-	    } else {
-		/*
-		 * use backward recurrence
-		 * 			x	  x^2	  x^2
-		 *  J(n,x)/J(n-1,x) =  ----   ------   ------   .....
-		 *			2n  - 2(n+1) - 2(n+2)
-		 *
-		 * 			1	  1	    1
-		 *  (for large x)   =  ----  ------   ------   .....
-		 *			2n   2(n+1)   2(n+2)
-		 *			-- - ------ - ------ -
-		 *			 x	 x		 x
-		 *
-		 * Let w = 2n/x and h = 2/x, then the above quotient
-		 * is equal to the continued fraction:
-		 *		    1
-		 *	= -----------------------
-		 *			   1
-		 *	   w - -----------------
-		 *			  1
-		 * 			w+h - ---------
-		 *			   w+2h - ...
-		 *
-		 * To determine how many terms needed, let
-		 * Q(0) = w, Q(1) = w(w+h) - 1,
-		 * Q(k) = (w+k*h)*Q(k-1) - Q(k-2),
-		 * When Q(k) > 1e4	good for single
-		 * When Q(k) > 1e9	good for double
-		 * When Q(k) > 1e17	good for quaduple
-		 */
-	    /* determin k */
-		GENERIC t, v;
-		double q0, q1, h, tmp; int k, m;
-		w  = (n+n)/(double)x; h = 2.0/(double)x;
-		q0 = w;  z = w + h; q1 = w*z - 1.0; k = 1;
-		while (q1 < 1.0e9) {
-			k += 1; z += h;
-			tmp = z*q1 - q0;
-			q0 = q1;
-			q1 = tmp;
-		}
-		m = n+n;
-		for (t = zero, i = 2*(n+k); i >= m; i -= 2) t = one/(i/x-t);
-		a = t;
-		b = one;
-		/*
-		 * estimate log((2/x)^n*n!) = n*log(2/x)+n*ln(n)
-		 *  hence, if n*(log(2n/x)) > ...
-		 *  single 8.8722839355e+01
-		 *  double 7.09782712893383973096e+02
-		 *  long double 1.1356523406294143949491931077970765006170e+04
-		 *  then recurrent value may overflow and the result is
-		 *  likely underflow to zero
-		 */
-		tmp = n;
-		v = two/x;
-		tmp = tmp*log(fabs(v*tmp));
-		if (tmp < 7.09782712893383973096e+02) {
-			    for (i = n-1; i > 0; i--) {
-				temp = b;
-				b = ((i+i)/x)*b - a;
-			    a = temp;
-				}
+	} else {
+		if (x < 1e-9) {	/* use J(n,x) = 1/n!*(x/2)^n */
+			b = pow(0.5*x, (GENERIC) n);
+			if (b != zero) {
+				for (a = one, i = 1; i <= n; i++)
+					a *= (GENERIC)i;
+				b = b/a;
+			}
 		} else {
+			/*
+			 * use backward recurrence
+			 *			x	  x^2	  x^2
+			 *  J(n,x)/J(n-1,x) =  ----   ------   ------   .....
+			 *			2n  - 2(n+1) - 2(n+2)
+			 *
+			 *			1	  1	    1
+			 *  (for large x)   =  ----  ------   ------   .....
+			 *			2n   2(n+1)   2(n+2)
+			 *			-- - ------ - ------ -
+			 *			 x	 x		 x
+			 *
+			 * Let w = 2n/x and h = 2/x, then the above quotient
+			 * is equal to the continued fraction:
+			 *		    1
+			 *	= -----------------------
+			 *			   1
+			 *	   w - -----------------
+			 *			  1
+			 *			w+h - ---------
+			 *			   w+2h - ...
+			 *
+			 * To determine how many terms needed, let
+			 * Q(0) = w, Q(1) = w(w+h) - 1,
+			 * Q(k) = (w+k*h)*Q(k-1) - Q(k-2),
+			 * When Q(k) > 1e4	good for single
+			 * When Q(k) > 1e9	good for double
+			 * When Q(k) > 1e17	good for quaduple
+			 */
+			/* determine k */
+			GENERIC t, v;
+			double q0, q1, h, tmp;
+			int k, m;
+			w  = (n+n)/(double)x;
+			h = 2.0/(double)x;
+			q0 = w;
+			z = w + h;
+			q1 = w*z - 1.0;
+			k = 1;
+
+			while (q1 < 1.0e9) {
+				k += 1;
+				z += h;
+				tmp = z*q1 - q0;
+				q0 = q1;
+				q1 = tmp;
+			}
+			m = n+n;
+			for (t = zero, i = 2*(n+k); i >= m; i -= 2)
+				t = one/(i/x-t);
+			a = t;
+			b = one;
+			/*
+			 * estimate log((2/x)^n*n!) = n*log(2/x)+n*ln(n)
+			 * hence, if n*(log(2n/x)) > ...
+			 * single 8.8722839355e+01
+			 * double 7.09782712893383973096e+02
+			 * long double 1.1356523406294143949491931077970765006170e+04
+			 * then recurrent value may overflow and the result is
+			 * likely underflow to zero
+			 */
+			tmp = n;
+			v = two/x;
+			tmp = tmp*log(fabs(v*tmp));
+			if (tmp < 7.09782712893383973096e+02) {
 				for (i = n-1; i > 0; i--) {
-				    temp = b;
-				    b = ((i+i)/x)*b - a;
-				    a = temp;
+					temp = b;
+					b = ((i+i)/x)*b - a;
+					a = temp;
+				}
+			} else {
+				for (i = n-1; i > 0; i--) {
+					temp = b;
+					b = ((i+i)/x)*b - a;
+					a = temp;
 					if (b > 1e100) {
 						a /= b;
 						t /= b;
 						b  = 1.0;
 					}
 				}
-		}
+			}
 			b = (t*j0(x)/b);
-	    }
+		}
 	}
-	if (sgn == 1)
+	if (sgn != 0)
 		return (-b);
 	else
 		return (b);
 }
 
 GENERIC
-yn(int n, GENERIC x) {
+yn(int n, GENERIC x)
+{
 	int i;
 	int sign;
 	GENERIC a, b, temp = 0, ox, on;
 
-	ox = x; on = (GENERIC)n;
+	ox = x;
+	on = (GENERIC)n;
 	if (isnan(x))
 		return (x*x);	/* + -> * for Cheetah */
 	if (x <= zero) {
@@ -245,9 +268,9 @@
 			return (_SVID_libm_err((GENERIC)n, x, 13));
 		}
 	}
-	if (!((int) _lib_version == libm_ieee ||
-		(__xpg6 & _C99SUSv3_math_errexcept) != 0)) {
-	    if (x > X_TLOSS)
+	if (!((int)_lib_version == libm_ieee ||
+	    (__xpg6 & _C99SUSv3_math_errexcept) != 0)) {
+		if (x > X_TLOSS)
 			return (_SVID_libm_err(on, ox, 39));
 	}
 	sign = 1;
@@ -273,15 +296,23 @@
 				 *    n	sin(xn)*sqt2	cos(xn)*sqt2
 				 *	----------------------------------
 				 *	 0	 s-c		 c+s
-				 *	 1	-s-c 		-c+s
+				 *	 1	-s-c		-c+s
 				 *	 2	-s+c		-c-s
 				 *	 3	 s+c		 c-s
 				 */
 		switch (n&3) {
-		    case 0: temp =  sin(x)-cos(x); break;
-		    case 1: temp = -sin(x)-cos(x); break;
-		    case 2: temp = -sin(x)+cos(x); break;
-		    case 3: temp =  sin(x)+cos(x); break;
+		case 0:
+			temp =  sin(x)-cos(x);
+			break;
+		case 1:
+			temp = -sin(x)-cos(x);
+			break;
+		case 2:
+			temp = -sin(x)+cos(x);
+			break;
+		case 3:
+			temp =  sin(x)+cos(x);
+			break;
 		}
 		b = invsqrtpi*temp/sqrt(x);
 	} else {
--- old/usr/src/lib/libm/common/C/tanh.c	2019-06-04 01:04:26.586871204 +0000
+++ new/usr/src/lib/libm/common/C/tanh.c	2019-06-04 01:04:26.603398928 +0000
@@ -67,7 +67,8 @@
 /* INDENT ON */
 
 double
-tanh(double x) {
+tanh(double x)
+{
 	double t, y, z;
 	int signx;
 	volatile double dummy __unused;
@@ -94,7 +95,7 @@
 	} else if (!finite(t))
 		return (copysign(1.0, x));
 	else
-		return (signx == 1 ? -z + small * small : z - small * small);
+		return ((signx != 0) ? -z + small * small : z - small * small);
 
-	return (signx == 1 ? -z : z);
+	return ((signx != 0) ? -z : z);
 }
--- old/usr/src/lib/libm/common/LD/__rem_pio2l.c	2019-06-04 01:04:27.015278098 +0000
+++ new/usr/src/lib/libm/common/LD/__rem_pio2l.c	2019-06-04 01:04:27.032235549 +0000
@@ -27,7 +27,8 @@
  * Use is subject to license terms.
  */
 
-/* __rem_pio2l(x,y)
+/*
+ * __rem_pio2l(x,y)
  *
  * return the remainder of x rem pi/2 in y[0]+y[1]
  * by calling __rem_pio2m
@@ -70,7 +71,7 @@
 	w = (long double)v[0];
 	y[0] = z + w;
 	y[1] = z - (y[0] - w);
-	if (sign == 1) {
+	if (sign != 0) {
 		y[0] = -y[0];
 		y[1] = -y[1];
 		return (-n);
--- old/usr/src/lib/libm/common/LD/jnl.c	2019-06-04 01:04:27.465730724 +0000
+++ new/usr/src/lib/libm/common/LD/jnl.c	2019-06-04 01:04:27.483056814 +0000
@@ -68,7 +68,8 @@
 one  = 1.0L;
 
 GENERIC
-jnl(n, x) int n; GENERIC x; {
+jnl(int n, GENERIC x)
+{
 	int i, sgn;
 	GENERIC a, b, temp = 0, z, w;
 
@@ -80,11 +81,14 @@
 		n = -n;
 		x = -x;
 	}
-	if (n == 0) return (j0l(x));
-	if (n == 1) return (j1l(x));
-	if (x != x) return x+x;
+	if (n == 0)
+		return (j0l(x));
+	if (n == 1)
+		return (j1l(x));
+	if (x != x)
+		return (x+x);
 	if ((n&1) == 0)
-		sgn = 0; 			/* even n */
+		sgn = 0;			/* even n */
 	else
 		sgn = signbitl(x);	/* old n  */
 	x = fabsl(x);
@@ -94,7 +98,7 @@
 			 * Safe to use
 			 * J(n+1,x)=2n/x *J(n,x)-J(n-1,x)
 			 */
-	    if (x > 1.0e91L) {
+		if (x > 1.0e91L) {
 				/*
 				 * x >> n**2
 				 *  Jn(x) = cos(x-(2n+1)*pi/4)*sqrt(2/x*pi)
@@ -105,78 +109,95 @@
 				 *	   n	sin(xn)*sqt2	cos(xn)*sqt2
 				 *	----------------------------------
 				 *	   0	 s-c		 c+s
-				 *	   1	-s-c 		-c+s
+				 *	   1	-s-c		-c+s
 				 *	   2	-s+c		-c-s
 				 *	   3	 s+c		 c-s
 				 */
-		switch (n&3) {
-		    case 0: temp =  cosl(x)+sinl(x); break;
-		    case 1: temp = -cosl(x)+sinl(x); break;
-		    case 2: temp = -cosl(x)-sinl(x); break;
-		    case 3: temp =  cosl(x)-sinl(x); break;
-		}
-		b = invsqrtpi*temp/sqrtl(x);
-	    } else {
+			switch (n&3) {
+			case 0:
+				temp =  cosl(x)+sinl(x);
+				break;
+			case 1:
+				temp = -cosl(x)+sinl(x);
+				break;
+			case 2:
+				temp = -cosl(x)-sinl(x);
+				break;
+			case 3:
+				temp =  cosl(x)-sinl(x);
+				break;
+			}
+			b = invsqrtpi*temp/sqrtl(x);
+		} else {
 			a = j0l(x);
 			b = j1l(x);
 			for (i = 1; i < n; i++) {
-		    temp = b;
-		    b = b*((GENERIC)(i+i)/x) - a; /* avoid underflow */
-		    a = temp;
+				temp = b;
+				/* avoid underflow */
+				b = b*((GENERIC)(i+i)/x) - a;
+				a = temp;
 			}
-	    }
-	} else {
-	    if (x < 1e-17L) {	/* use J(n,x) = 1/n!*(x/2)^n */
-		b = powl(0.5L*x, (GENERIC) n);
-		if (b != zero) {
-		    for (a = one, i = 1; i <= n; i++) a *= (GENERIC)i;
-		    b = b/a;
-		}
-	    } else {
-		/*
-		 * use backward recurrence
-		 * 			x      x^2      x^2
-		 *  J(n,x)/J(n-1,x) =  ----   ------   ------   .....
-		 *			2n  - 2(n+1) - 2(n+2)
-		 *
-		 * 			1      1        1
-		 *  (for large x)   =  ----  ------   ------   .....
-		 *			2n   2(n+1)   2(n+2)
-		 *			-- - ------ - ------ -
-		 *			 x     x         x
-		 *
-		 * Let w = 2n/x and h=2/x, then the above quotient
-		 * is equal to the continued fraction:
-		 *		    1
-		 *	= -----------------------
-		 *		       1
-		 *	   w - -----------------
-		 *			  1
-		 * 	        w+h - ---------
-		 *		       w+2h - ...
-		 *
-		 * To determine how many terms needed, let
-		 * Q(0) = w, Q(1) = w(w+h) - 1,
-		 * Q(k) = (w+k*h)*Q(k-1) - Q(k-2),
-		 * When Q(k) > 1e4	good for single
-		 * When Q(k) > 1e9	good for double
-		 * When Q(k) > 1e17	good for quaduple
-		 */
-	    /* determin k */
-		GENERIC t, v;
-		double q0, q1, h, tmp; int k, m;
-		w  = (n+n)/(double)x; h = 2.0/(double)x;
-		q0 = w;  z = w+h; q1 = w*z - 1.0; k = 1;
-		while (q1 < 1.0e17) {
-			k += 1; z += h;
-			tmp = z*q1 - q0;
-			q0 = q1;
-			q1 = tmp;
 		}
-		m = n+n;
-		for (t = zero, i = 2*(n+k); i >= m; i -= 2) t = one/(i/x-t);
-		a = t;
-		b = one;
+	} else {
+		if (x < 1e-17L) {	/* use J(n,x) = 1/n!*(x/2)^n */
+			b = powl(0.5L*x, (GENERIC)n);
+			if (b != zero) {
+				for (a = one, i = 1; i <= n; i++)
+					a *= (GENERIC)i;
+				b = b/a;
+			}
+		} else {
+			/*
+			 * use backward recurrence
+			 *			x      x^2	x^2
+			 *  J(n,x)/J(n-1,x) =  ----   ------   ------   .....
+			 *			2n  - 2(n+1) - 2(n+2)
+			 *
+			 *			1      1	1
+			 *  (for large x)   =  ----  ------   ------   .....
+			 *			2n   2(n+1)   2(n+2)
+			 *			-- - ------ - ------ -
+			 *			 x     x         x
+			 *
+			 * Let w = 2n/x and h=2/x, then the above quotient
+			 * is equal to the continued fraction:
+			 *		    1
+			 *	= -----------------------
+			 *		       1
+			 *	   w - -----------------
+			 *			  1
+			 *		w+h - ---------
+			 *		       w+2h - ...
+			 *
+			 * To determine how many terms needed, let
+			 * Q(0) = w, Q(1) = w(w+h) - 1,
+			 * Q(k) = (w+k*h)*Q(k-1) - Q(k-2),
+			 * When Q(k) > 1e4	good for single
+			 * When Q(k) > 1e9	good for double
+			 * When Q(k) > 1e17	good for quaduple
+			 */
+			/* determine k */
+			GENERIC t, v;
+			double q0, q1, h, tmp;
+			int k, m;
+			w  = (n+n)/(double)x;
+			h = 2.0/(double)x;
+			q0 = w;
+			z = w+h;
+			q1 = w*z - 1.0;
+			k = 1;
+			while (q1 < 1.0e17) {
+				k += 1;
+				z += h;
+				tmp = z*q1 - q0;
+				q0 = q1;
+				q1 = tmp;
+			}
+			m = n+n;
+			for (t = zero, i = 2*(n+k); i >= m; i -= 2)
+				t = one/(i/x-t);
+			a = t;
+			b = one;
 			/*
 			 * Estimate log((2/x)^n*n!) = n*log(2/x)+n*ln(n)
 			 * hence, if n*(log(2n/x)) > ...
@@ -186,58 +207,63 @@
 			 * then recurrent value may overflow and the result is
 			 * likely underflow to zero.
 			 */
-		tmp = n;
-		v = two/x;
-		tmp = tmp*logl(fabsl(v*tmp));
-		if (tmp < 1.1356523406294143949491931077970765e+04L) {
+			tmp = n;
+			v = two/x;
+			tmp = tmp*logl(fabsl(v*tmp));
+			if (tmp < 1.1356523406294143949491931077970765e+04L) {
 				for (i = n-1; i > 0; i--) {
-				temp = b;
-				b = ((i+i)/x)*b - a;
-				a = temp;
+					temp = b;
+					b = ((i+i)/x)*b - a;
+					a = temp;
 				}
-		} else {
+			} else {
 				for (i = n-1; i > 0; i--) {
-				temp = b;
-				b = ((i+i)/x)*b - a;
-				a = temp;
-			if (b > 1e1000L) {
+					temp = b;
+					b = ((i+i)/x)*b - a;
+					a = temp;
+					if (b > 1e1000L) {
 						a /= b;
 						t /= b;
 						b  = 1.0;
 					}
 				}
-		}
+			}
 			b = (t*j0l(x)/b);
-	    }
+		}
 	}
-	if (sgn == 1)
-		return -b;
+	if (sgn != 0)
+		return (-b);
 	else
-		return b;
+		return (b);
 }
 
 GENERIC
-ynl(n, x) int n; GENERIC x; {
+ynl(int n, GENERIC x)
+{
 	int i;
 	int sign;
 	GENERIC a, b, temp = 0;
 
 	if (x != x)
-		return x+x;
+		return (x+x);
 	if (x <= zero) {
 		if (x == zero)
-			return -one/zero;
+			return (-one/zero);
 		else
-			return zero/zero;
+			return (zero/zero);
 	}
 	sign = 1;
 	if (n < 0) {
 		n = -n;
-		if ((n&1) == 1) sign = -1;
+		if ((n&1) == 1)
+			sign = -1;
 	}
-	if (n == 0) return (y0l(x));
-	if (n == 1) return (sign*y1l(x));
-	if (!finitel(x)) return zero;
+	if (n == 0)
+		return (y0l(x));
+	if (n == 1)
+		return (sign*y1l(x));
+	if (!finitel(x))
+		return (zero);
 
 	if (x > 1.0e91L) {
 				/*
@@ -249,16 +275,24 @@
 				 *
 				 *	   n	sin(xn)*sqt2	cos(xn)*sqt2
 				 *	----------------------------------
-				 * 	   0	 s-c		 c+s
-				 *	   1	-s-c 		-c+s
-				 * 	   2	-s+c		-c-s
+				 *	   0	 s-c		 c+s
+				 *	   1	-s-c		-c+s
+				 *	   2	-s+c		-c-s
 				 *	   3	 s+c		 c-s
 				 */
 		switch (n&3) {
-		    case 0: temp =  sinl(x)-cosl(x); break;
-		    case 1: temp = -sinl(x)-cosl(x); break;
-		    case 2: temp = -sinl(x)+cosl(x); break;
-		    case 3: temp =  sinl(x)+cosl(x); break;
+		case 0:
+			temp =  sinl(x)-cosl(x);
+			break;
+		case 1:
+			temp = -sinl(x)-cosl(x);
+			break;
+		case 2:
+			temp = -sinl(x)+cosl(x);
+			break;
+		case 3:
+			temp =  sinl(x)+cosl(x);
+			break;
 		}
 		b = invsqrtpi*temp/sqrtl(x);
 	} else {
@@ -277,7 +311,7 @@
 		}
 	}
 	if (sign > 0)
-		return b;
+		return (b);
 	else
-		return -b;
+		return (-b);
 }
--- old/usr/src/lib/libm/common/Q/__rem_pio2l.c	2019-06-04 01:04:27.951922422 +0000
+++ new/usr/src/lib/libm/common/Q/__rem_pio2l.c	2019-06-04 01:04:27.970578668 +0000
@@ -50,7 +50,8 @@
 	pio4   = 0.7853981633974483096156608458198757210495L;
 
 int
-__rem_pio2l(long double x, long double *y) {
+__rem_pio2l(long double x, long double *y)
+{
 	long double z, w;
 	double t[5], v[5];
 	int e0, i, nx, n, sign;
@@ -66,19 +67,19 @@
 	e0 = ilogbl(z) - 23;
 	z = scalbnl(z, -e0);
 	for (i = 0; i < 5; i++) {
-		t[i] = (double) ((int) (z));
-		z = (z - (long double) t[i]) * two24l;
+		t[i] = (double)((int)(z));
+		z = (z - (long double)t[i]) * two24l;
 	}
 	nx = 5;
 	while (t[nx - 1] == 0.0)
 		nx--;		/* skip zero term */
 	ipio2 = _TBL_ipio2l_inf;
-	n = __rem_pio2m(t, v, e0, nx, 3, (const int *) ipio2);
-	z = (long double) v[2] + (long double) v[1];
-	w = (long double) v[0];
+	n = __rem_pio2m(t, v, e0, nx, 3, (const int *)ipio2);
+	z = (long double)v[2] + (long double)v[1];
+	w = (long double)v[0];
 	y[0] = z + w;
 	y[1] = z - (y[0] - w);
-	if (sign == 1) {
+	if (sign != 0) {
 		y[0] = -y[0];
 		y[1] = -y[1];
 		return (-n);
--- old/usr/src/lib/libm/common/Q/atan2l.c	2019-06-04 01:04:28.418422894 +0000
+++ new/usr/src/lib/libm/common/Q/atan2l.c	2019-06-04 01:04:28.435422162 +0000
@@ -63,7 +63,7 @@
 
 static const long double
 	zero	=  0.0L,
-	tiny 	=  1.0e-40L,
+	tiny	=  1.0e-40L,
 	one	=  1.0L,
 	half	=  0.5L,
 	PI3o4	=  2.356194490192344928846982537459627163148L,
@@ -73,7 +73,8 @@
 	PI_lo	=  8.671810130123781024797044026043351968762e-35L;
 
 long double
-atan2l(long double y, long double x) {
+atan2l(long double y, long double x)
+{
 	long double t, z;
 	int k, m, signy, signx;
 
@@ -83,7 +84,8 @@
 	signx = signbitl(x);
 	if (x == one)
 		return (atanl(y));
-	m = signy + signx + signx;
+	/* Ensure sign indicators are boolean */
+	m = (signy != 0) + (signx != 0) + (signx != 0);
 
 	/* when y = 0 */
 	if (y == zero)
@@ -100,7 +102,7 @@
 
 	/* when x = 0 */
 	if (x == zero)
-		return (signy == 1 ? -PIo2 - tiny : PIo2 + tiny);
+		return (signy != 0 ? -PIo2 - tiny : PIo2 + tiny);
 
 	/* when x is INF */
 	if (!finitel(x)) {
@@ -130,7 +132,7 @@
 	}
 	/* when y is INF */
 	if (!finitel(y))
-		return (signy == 1 ? -PIo2 - tiny : PIo2 + tiny);
+		return (signy != 0 ? -PIo2 - tiny : PIo2 + tiny);
 
 	/* compute y/x */
 	x = fabsl(x);
@@ -156,5 +158,5 @@
 		return ((z - t) - PI);	/* atan(-,-) */
 	}
 	/* NOTREACHED */
-    return 0.0L;
+	return (0.0L);
 }
--- old/usr/src/lib/libm/common/Q/jnl.c	2019-06-04 01:04:28.887936083 +0000
+++ new/usr/src/lib/libm/common/Q/jnl.c	2019-06-04 01:04:28.905248472 +0000
@@ -68,7 +68,8 @@
 one  = 1.0L;
 
 GENERIC
-jnl(n, x) int n; GENERIC x; {
+jnl(int n, GENERIC x)
+{
 	int i, sgn;
 	GENERIC a, b, temp, z, w;
 
@@ -87,7 +88,7 @@
 	if (x != x)
 		return (x+x);
 	if ((n&1) == 0)
-		sgn = 0; 			/* even n */
+		sgn = 0;			/* even n */
 	else
 		sgn = signbitl(x);	/* old n  */
 	x = fabsl(x);
@@ -97,7 +98,7 @@
 					 * Safe to use
 					 * J(n+1,x)=2n/x *J(n,x)-J(n-1,x)
 					 */
-	    if (x > 1.0e91L) {
+		if (x > 1.0e91L) {
 				/*
 				 * x >> n**2
 				 *  Jn(x) = cos(x-(2n+1)*pi/4)*sqrt(2/x*pi)
@@ -108,119 +109,137 @@
 				 *	   n	sin(xn)*sqt2	cos(xn)*sqt2
 				 *	----------------------------------
 				 *	   0	 s-c		 c+s
-				 *	   1	-s-c 		-c+s
+				 *	   1	-s-c		-c+s
 				 *	   2	-s+c		-c-s
 				 *	   3	 s+c		 c-s
 				 */
-		switch (n&3) {
-		    case 0: temp =  cosl(x)+sinl(x); break;
-		    case 1: temp = -cosl(x)+sinl(x); break;
-		    case 2: temp = -cosl(x)-sinl(x); break;
-		    case 3: temp =  cosl(x)-sinl(x); break;
-		}
-		b = invsqrtpi*temp/sqrtl(x);
-	    } else {
+			switch (n&3) {
+			case 0:
+				temp =  cosl(x)+sinl(x);
+				break;
+			case 1:
+				temp = -cosl(x)+sinl(x);
+				break;
+			case 2:
+				temp = -cosl(x)-sinl(x);
+				break;
+			case 3:
+				temp =  cosl(x)-sinl(x);
+				break;
+			}
+			b = invsqrtpi*temp/sqrtl(x);
+		} else {
 			a = j0l(x);
 			b = j1l(x);
 			for (i = 1; i < n; i++) {
-		    temp = b;
-		    b = b*((GENERIC)(i+i)/x) - a; /* avoid underflow */
-		    a = temp;
+				temp = b;
+				/* avoid underflow */
+				b = b*((GENERIC)(i+i)/x) - a;
+				a = temp;
 			}
-	    }
-	} else {
-	    if (x < 1e-17L) {	/* use J(n,x) = 1/n!*(x/2)^n */
-		b = powl(0.5L*x, (GENERIC)n);
-		if (b != zero) {
-		    for (a = one, i = 1; i <= n; i++) a *= (GENERIC)i;
-		    b = b/a;
-		}
-	    } else {
-		/* use backward recurrence */
-		/*
-		 * 			x      x^2      x^2
-		 *  J(n,x)/J(n-1,x) =  ----   ------   ------   .....
-		 *			2n  - 2(n+1) - 2(n+2)
-		 *
-		 * 			1      1        1
-		 *  (for large x)   =  ----  ------   ------   .....
-		 *			2n   2(n+1)   2(n+2)
-		 *			-- - ------ - ------ -
-		 *			 x     x         x
-		 *
-		 * Let w = 2n/x and h=2/x, then the above quotient
-		 * is equal to the continued fraction:
-		 *		    1
-		 *	= -----------------------
-		 *		       1
-		 *	   w - -----------------
-		 *			  1
-		 * 	        w+h - ---------
-		 *		       w+2h - ...
-		 *
-		 * To determine how many terms needed, let
-		 * Q(0) = w, Q(1) = w(w+h) - 1,
-		 * Q(k) = (w+k*h)*Q(k-1) - Q(k-2),
-		 * When Q(k) > 1e4	good for single
-		 * When Q(k) > 1e9	good for double
-		 * When Q(k) > 1e17	good for quaduple
-		 */
-	    /* determin k */
-		GENERIC t, v;
-		double q0, q1, h, tmp; int k, m;
-		w  = (n+n)/(double)x; h = 2.0/(double)x;
-		q0 = w;  z = w+h; q1 = w*z - 1.0; k = 1;
-		while (q1 < 1.0e17) {
-			k += 1; z += h;
-			tmp = z*q1 - q0;
-			q0 = q1;
-			q1 = tmp;
 		}
-		m = n+n;
-		for (t = zero, i = 2*(n+k); i >= m; i -= 2) t = one/(i/x-t);
-		a = t;
-		b = one;
-                /*
-		 * estimate log((2/x)^n*n!) = n*log(2/x)+n*ln(n)
-                 * hence, if n*(log(2n/x)) > ...
-                 *  single 8.8722839355e+01
-                 *  double 7.09782712893383973096e+02
-                 *  long double 1.1356523406294143949491931077970765006170e+04
-                 *  then recurrent value may overflow and the result is
-                 *  likely underflow to zero
-                 */
-		tmp = n;
-		v = two/x;
-		tmp = tmp*logl(fabsl(v*tmp));
-		if (tmp < 1.1356523406294143949491931077970765e+04L) {
-				for (i = n-1; i > 0; i--) {
-		        temp = b;
-		        b = ((i+i)/x)*b - a;
-		        a = temp;
-	     	    }
+	} else {
+		if (x < 1e-17L) {	/* use J(n,x) = 1/n!*(x/2)^n */
+			b = powl(0.5L*x, (GENERIC)n);
+			if (b != zero) {
+				for (a = one, i = 1; i <= n; i++)
+					a *= (GENERIC)i;
+				b = b/a;
+			}
 		} else {
+			/* use backward recurrence */
+			/*
+			 *			x      x^2	x^2
+			 *  J(n,x)/J(n-1,x) =  ----   ------   ------	.....
+			 *			2n  - 2(n+1) - 2(n+2)
+			 *
+			 *			1      1	1
+			 *  (for large x)   =  ----  ------   ------   .....
+			 *			2n   2(n+1)   2(n+2)
+			 *			-- - ------ - ------ -
+			 *			 x     x	 x
+			 *
+			 * Let w = 2n/x and h=2/x, then the above quotient
+			 * is equal to the continued fraction:
+			 *		    1
+			 *	= -----------------------
+			 *		       1
+			 *	   w - -----------------
+			 *			  1
+			 *		w+h - ---------
+			 *		       w+2h - ...
+			 *
+			 * To determine how many terms needed, let
+			 * Q(0) = w, Q(1) = w(w+h) - 1,
+			 * Q(k) = (w+k*h)*Q(k-1) - Q(k-2),
+			 * When Q(k) > 1e4	good for single
+			 * When Q(k) > 1e9	good for double
+			 * When Q(k) > 1e17	good for quaduple
+			 */
+			/* determine k */
+			GENERIC t, v;
+			double q0, q1, h, tmp;
+			int k, m;
+			w  = (n+n)/(double)x;
+			h = 2.0/(double)x;
+			q0 = w;
+			z = w+h;
+			q1 = w*z - 1.0;
+			k = 1;
+			while (q1 < 1.0e17) {
+				k += 1;
+				z += h;
+				tmp = z*q1 - q0;
+				q0 = q1;
+				q1 = tmp;
+			}
+			m = n+n;
+			for (t = zero, i = 2*(n+k); i >= m; i -= 2)
+				t = one/(i/x-t);
+			a = t;
+			b = one;
+			/*
+			 * estimate log((2/x)^n*n!) = n*log(2/x)+n*ln(n)
+			 * hence, if n*(log(2n/x)) > ...
+			 *  single 8.8722839355e+01
+			 *  double 7.09782712893383973096e+02
+			 *  long double 1.1356523406294143949491931077970765006170e+04
+			 *  then recurrent value may overflow and the result is
+			 *  likely underflow to zero
+			 */
+			tmp = n;
+			v = two/x;
+			tmp = tmp*logl(fabsl(v*tmp));
+			if (tmp < 1.1356523406294143949491931077970765e+04L) {
+				for (i = n-1; i > 0; i--) {
+					temp = b;
+					b = ((i+i)/x)*b - a;
+					a = temp;
+				}
+			} else {
 				for (i = n-1; i > 0; i--) {
-		        temp = b;
-		        b = ((i+i)/x)*b - a;
-		        a = temp;
-			if (b > 1e1000L) {
-                            a /= b;
-                            t /= b;
-                            b  = 1.0;
-                        }
-	     	    }
+					temp = b;
+					b = ((i+i)/x)*b - a;
+					a = temp;
+					if (b > 1e1000L) {
+						a /= b;
+						t /= b;
+						b  = 1.0;
+					}
+				}
+			}
+			b = (t*j0l(x)/b);
 		}
-	    	b = (t*j0l(x)/b);
-	    }
 	}
-	if (sgn == 1)
+	if (sgn != 0)
 		return (-b);
 	else
 		return (b);
 }
 
-GENERIC ynl(n, x)
-int n; GENERIC x; {
+GENERIC
+ynl(int n, GENERIC x)
+{
 	int i;
 	int sign;
 	GENERIC a, b, temp;
@@ -245,24 +264,34 @@
 	if (!finitel(x))
 		return (zero);
 
-	if (x > 1.0e91L) {	/* x >> n**2
-				    Jn(x) = cos(x-(2n+1)*pi/4)*sqrt(2/x*pi)
-				    Yn(x) = sin(x-(2n+1)*pi/4)*sqrt(2/x*pi)
-				    Let s = sin(x), c = cos(x),
-					xn = x-(2n+1)*pi/4, sqt2 = sqrt(2), then
-
-					   n	sin(xn)*sqt2	cos(xn)*sqt2
-					----------------------------------
-					   0	 s-c		 c+s
-					   1	-s-c 		-c+s
-					   2	-s+c		-c-s
-					   3	 s+c		 c-s
-				 */
+	if (x > 1.0e91L) {
+		/*
+		 * x >> n**2
+		 *   Jn(x) = cos(x-(2n+1)*pi/4)*sqrt(2/x*pi)
+		 *   Yn(x) = sin(x-(2n+1)*pi/4)*sqrt(2/x*pi)
+		 *   Let s = sin(x), c = cos(x),
+		 *	xn = x-(2n+1)*pi/4, sqt2 = sqrt(2), then
+		 *
+		 *	   n	sin(xn)*sqt2	cos(xn)*sqt2
+		 *	----------------------------------
+		 *	   0	 s-c		 c+s
+		 *	   1	-s-c		-c+s
+		 *	   2	-s+c		-c-s
+		 *	   3	 s+c		 c-s
+		 */
 		switch (n&3) {
-		    case 0: temp =  sinl(x)-cosl(x); break;
-		    case 1: temp = -sinl(x)-cosl(x); break;
-		    case 2: temp = -sinl(x)+cosl(x); break;
-		    case 3: temp =  sinl(x)+cosl(x); break;
+		case 0:
+			temp =  sinl(x)-cosl(x);
+			break;
+		case 1:
+			temp = -sinl(x)-cosl(x);
+			break;
+		case 2:
+			temp = -sinl(x)+cosl(x);
+			break;
+		case 3:
+			temp =  sinl(x)+cosl(x);
+			break;
 		}
 		b = invsqrtpi*temp/sqrtl(x);
 	} else {
